'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _main = require('../sigma/main');

var _main2 = _interopRequireDefault(_main);

require('../sigma/plugins.animate');

require('../sigma/layout.noverlap');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**

NOverlap component, starts noverlap sigma plugin once component is mounted.
It supposes that sigma graph is already in place, therefore component should not be
mounted while graph is unavailable. It can be used within Sigma component if graph is
preloaded, or within loader component, like LoadJSON.

@param {number} [nodeMargin=5]    additional minimum space to apply around each and every node
@param {number} [scaleNodes=1.2]  multiplier,  larger nodes will have more space around
@param {number} [gridSize=20]   number of rows and columns to use when dividing the nodes up into cell
@param {number} [permittedExpansion=1.1]  maximum ratio to apply to the bounding box
@param {number} speed     larger value increases the speed at the cost of precision
@param {number} maxIterations  iterations to run the algorithm for before stopping it
@param {number} easing     camera easing type for camera transition
@param {number} duration     duration of the transition for the easing method

It accepts all the parameters of sigma.layout.noverlap plugin described on its github page:
[see sigma plugin page for more details](https://github.com/jacomyal/sigma.js/tree/master/plugins/sigma.layout.noverlap)

@example
<Sigma graph={data}>
 <NOverlap gridSize={10} maxIterations={100}/>
</Sigma>

**/

var NOverlap = function (_React$Component) {
	_inherits(NOverlap, _React$Component);

	function NOverlap(props) {
		_classCallCheck(this, NOverlap);

		var _this = _possibleConstructorReturn(this, (NOverlap.__proto__ || Object.getPrototypeOf(NOverlap)).call(this, props));

		_this.render = function () {
			return null;
		};

		_this.state = { running: false };
		return _this;
	}

	_createClass(NOverlap, [{
		key: 'componentDidMount',
		value: function componentDidMount() {
			this._refreshGraph();
		}
	}, {
		key: 'componentDidUpdate',
		value: function componentDidUpdate(prevProps, prevState) {
			if (prevState.running && !this.state.running) {
				if (this.props.sigma) this.props.sigma.refresh();
			}
		}
	}, {
		key: 'componentWillUnmount',
		value: function componentWillUnmount() {
			if (this.state.running && this.props.sigma) this.props.sigma.stopNoverlap();
		}
	}, {
		key: '_refreshGraph',
		value: function _refreshGraph() {
			var _this2 = this;

			var s = this.props.sigma;
			if (!_main2.default || !s) return;

			var listener = s.configNoverlap(this._stripOptions(this.props));

			listener.bind('stop', function () {
				_this2.setState({ running: false });
			});

			this.setState({ running: true });

			s.startNoverlap();
		}

		//strip noverlap options from component props

	}, {
		key: '_stripOptions',
		value: function _stripOptions(props) {
			return Object.assign({}, props, { sigma: undefined });
		}
	}]);

	return NOverlap;
}(_react2.default.Component);

NOverlap.propTypes = {
	nodes: require('react').PropTypes.arrayOf(require('react').PropTypes.any),
	nodeMargin: require('react').PropTypes.number,
	scaleNodes: require('react').PropTypes.number,
	gridSize: require('react').PropTypes.number,
	permittedExpansion: require('react').PropTypes.number,
	speed: require('react').PropTypes.number,
	maxIterations: require('react').PropTypes.number,
	easing: require('react').PropTypes.any,
	duration: require('react').PropTypes.number,
	sigma: require('react').PropTypes.any
};
exports.default = NOverlap;